==> com.liferay.headless.delivery.impl-3.0.9-sources.jar: com/liferay/headless/delivery/internal/jaxrs/exception/mapper/DocumentFileExtensionExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.headless.delivery.internal.jaxrs.exception.mapper;

import com.liferay.document.library.kernel.exception.FileExtensionException;

import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;

import org.osgi.service.component.annotations.Component;

/**
 * Converts any {@code FileExtensionException} to a {@code 400} error.
 *
 * @author Alejandro Hernández
 */
@Component(
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Delivery)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Delivery.DocumentFileExtensionExceptionMapper"
	},
	service = ExceptionMapper.class
)
public class DocumentFileExtensionExceptionMapper
	implements ExceptionMapper<FileExtensionException> {

	@Override
	public Response toResponse(FileExtensionException fee) {
		return Response.status(
			400
		).type(
			MediaType.TEXT_PLAIN
		).entity(
			fee.getMessage()
		).build();
	}

}

==> com.liferay.headless.delivery.impl-5.0.24-sources.jar: com/liferay/headless/delivery/internal/jaxrs/exception/mapper/DocumentFileExtensionExceptionMapper.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.headless.delivery.internal.jaxrs.exception.mapper;

import com.liferay.document.library.kernel.exception.FileExtensionException;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.BaseExceptionMapper;
import com.liferay.portal.vulcan.jaxrs.exception.mapper.Problem;

import javax.ws.rs.core.Response;
import javax.ws.rs.ext.ExceptionMapper;

import org.osgi.service.component.annotations.Component;

/**
 * Converts any {@code FileExtensionException} to a {@code 400} error.
 *
 * @author Alejandro Hernández
 */
@Component(
	property = {
		"osgi.jaxrs.application.select=(osgi.jaxrs.name=Liferay.Headless.Delivery)",
		"osgi.jaxrs.extension=true",
		"osgi.jaxrs.name=Liferay.Headless.Delivery.DocumentFileExtensionExceptionMapper"
	},
	service = ExceptionMapper.class
)
public class DocumentFileExtensionExceptionMapper
	extends BaseExceptionMapper<FileExtensionException> {

	@Override
	protected Problem getProblem(
		FileExtensionException fileExtensionException) {

		return new Problem(
			Response.Status.BAD_REQUEST, fileExtensionException.getMessage());
	}

}
